
/**
 * Diese Klasse enthlt wesentlichen Methoden fr die Gesichtserkennung und verwaltet die dazu ntigen
 * Datenstrukturen. Dabei kommen insbesondere Felder fr die Personen und deren Gesichter zum Einsatz.
 * Diese werden mit Hilfe der Klassen GESICHT und PERSON verwaltet.
 * <br /><br />
 * Die Klasse GESICHT speichert eine Reihe von biometrischen Merkmale, die fr ein Bild erfasst wurden. 
 * Im Konstruktor der Klasse werden dazu die erfassten Koordinaten als Feld bergeben. Die Klasse GESICHT 
 * berechnet dann daraus die entsprechenden Merkmale. Ansonsten enthlt die Klasse diverse Get-Methoden.
 * <br /><br />
 * In der Klasse PERSON werden pro Person mehrere Gesichter verwaltet (verschiedene Referenzen). Neue
 * Gesichter knnen dazu mit der Methode addGesicht bergeben werden. Ansonsten enthlt die Klasse 
 * diverse Get-Methoden.
 * 
 * @version 1.0
 */

public class BIOMETRIE
{
    private double[] gewichte;

    private PERSON[] bekannte; 
    private PERSON[] unbekannte;
    private GESICHT[] gesichter;
    private int anzahlBekannte = 0;
    private int anzahlUnbekannte = 0;
    private int anzahlGesichter = 0;

    /**
     * Erzeugt Objekte der Klasse BIOMETRIE. Die Demo-Implementierung hlt ihre Datenbank im vollstndig Speicher und 
     * legt dazu Felder fr bekannte Personen (d.h. Personen mit bekannter Namen) und fr unbekannte Personen (d.h.
     * fr Personen, deren Identifizierung erfolgen soll) an. Die Anzahl ist im Konstrukor fest vorgegeben. Werden 
     * zu Laufzeit mehr bekannte bzw. unbekannte Personen erzeugt, erfolgt eine Fehlermeldung. 
     * 
     * Einige Methoden analysieren alle Gesichter aller Personen. Um hier die Schleifenstruktur einfacher zu halten
     * wird zudem ein Feld Gesichter angelegt, in dem alle Gesichter aller Personen referenziert werden. Auch 
     * deren maximale Anzahl wird im Konstruktor fest vorgegeben.
     * 
     * Zudem initialisiert der Konstruktor das Feld gewichte, mit dessem Hilfe sich die Abstandsberechnung zwischen
     * zwei Gesichtern beeinflussen lsst.
     */
    public BIOMETRIE()
    {
        // Textausgabe lschen
        System.out.print ('\f');

        // Demo-Daten erzeugen
        bekannte = new PERSON[50];
        unbekannte = new PERSON[50];
        gesichter = new GESICHT[400];
        generateDemoData();

        // Gewichte fr die Merkmale erzeugen
        gewichte = new double[bekannte[0].getGesicht(0).getMerkmalzahl()];
        for (int i=0; i<gewichte.length; i++) { gewichte[i] = 1; }

        // Test: Identifiziere alle unbekannten Gesichter
        testIdentifiziereGesicht();

        // Test: Vergleich eines unbekannten Gesichts mit allen anderen Gesichtern (gebe fr jedes Merkmal den Abstand aus)
        // reportAbstaende(unbekannte[0].getGesicht(0));

        // Test: Sind die Merkmale 8 und 9 (Abstand Auge zum Kopfrand links und rechts) symmetrisch? 
        // Gebe alle Gesichter an, bei denen dies nicht der Fall ist
        // reportSymmetrie(8,9,0.3);
        
        // Training fr bessere Gewichte oder Aussortieren von Merkmalen
        // Lassen Sie die Methode eine Zeit laufen und schauen Sie sich, z.B. mit Hilfe einer Tabellenkalkulation, die Verteilung
        // der Werte an. Auch ohne professionale Optimierungswerkzeuge kommt man so weiter.
        // reportZufaelligeGewichte();

    }

    /**
     * Berechnet den Abstand zwischen zwei Gesichtern. 
     * @param unbekannt Unbekanntes Gesicht
     * @param bekannt Bekanntes Gesicht
     * @param report Gibt an, ob Debug-Informationen ausgegeben werden sollen
     * @return Abstand der beiden Gesichter
     */
    public double abstand(GESICHT unbekannt, GESICHT bekannt, boolean report)
    {
        double anteil;
        double summe = 0;
        for (int i=0; i<bekannt.getMerkmalzahl(); i++)
        {
            anteil = Math.abs((unbekannt.getMerkmal(i)/unbekannt.getMerkmal(0)
                              -  bekannt.getMerkmal(i)/  bekannt.getMerkmal(0)));
            if (report) {System.out.println("  ["+i+": "+anteil+"]");}
            summe = summe + gewichte[i]*anteil;
        }
        return summe;
    }

    /**
     * Identifiziert ein unbekanntes Gesicht indem es in der Liste der bekannten Gesicht nach dem Gesicht 
     * sucht, dass dem unbekannten Gesicht am hnlichsten ist.
     * @param unbekannt Unbekanntes Gesicht
     * @param report Gibt an, ob Debug-Informationen ausgegeben werden sollen
     * @return Gesicht, das dem unbekannten Gesicht am hnlichsten ist
     */
    public GESICHT identifiziereGesicht(GESICHT unbekannt, boolean report)
    {
        GESICHT bestGesicht = null;

        // Der Startwert von minAbstand gibt die Schwelle vor, bis zu der ein Gesicht noch als gleich akzeptiert werden soll.
        // Bei einem hohen Wert wie diesem, wir quasi jedes Gesicht noch akzeptiert, d.h. immer ein Gesicht
        // als das mit dem geringsten Abstand identifiziert. Wo sollte die Schwelle besser liegen?
        double minAbstand = 10;        
        double aktAbstand;

        for (int g=0; g<anzahlGesichter; g++)
        {
            GESICHT kandidat = gesichter[g];
            if (kandidat != unbekannt) {
                aktAbstand = abstand(unbekannt,kandidat,false);
                if (aktAbstand < minAbstand) {
                    bestGesicht = kandidat;
                    minAbstand = aktAbstand;
                }
            }    
        }    

        if (report) 
        {
            if (bestGesicht == null) {
                System.out.println(unbekannt.getPerson().getPersonName()+" nicht erkannt. ["+minAbstand+"] (fehlerhaft)");
            }
            else
            {
                System.out.print(unbekannt.getPerson().getPersonName()+" erkannt als "+bestGesicht.getPerson().getPersonName()+" ["+minAbstand+"]");
                if (unbekannt.getPerson().getPersonName() != bestGesicht.getPerson().getPersonName()) { System.out.print(" (fehlerhaft)"); }
                System.out.println();    
            }
        }

        return bestGesicht;
    }

    /**
     * Identifiziert alle unbekannten Gesichter in des fr jedes unbekannte Gesicht die Methode identifiziereGesicht aufruft.
     */
    public void testIdentifiziereGesicht()
    {
        for (int u = 0; u < anzahlUnbekannte; u++)
        {
            identifiziereGesicht(unbekannte[u].getGesicht(0),true);
        }    
    }

    /* Erweiterungsidee:
     * Obige Methoden identifiziert eine Person anhand eines (!) ihrer Gesichter (d.h. dem Gesicht, das dem unbekannten Gesicht am
     * hnlichsten ist. Zur Verbesserung der Ergebnisse knnte diskutiert werden, ob die Heranziehung aller Gesichter einer Person vorteilhafter
     * wre (z.B. Vergleich mit einem durchschnittlichen Merkmalsatz oder mittlere Abweichung der Gesichter). Entsprechend knnte hier eine 
     * Methode public PERSON identifizierePerson(GESICHT unbekannt, boolean report) eingefgt werden.
     */

    /* Erweiterungsidee:
     * Obige Methoden sind fr den Identifizierungsmodus. Wie mssen die entsprechenden Verifikationsmethoden aussehen?
     */

    /**
     *  Erzeugt ein Objekt der Klasse PERSON mit den bergebenen Parametern. Der Aufruf gibt eine Fehlermeldung aus, wenn kein
     *  Speicherplatz mehr fr die PERSON zur Verfgung steht.
     *  @param aName Name der Person
     *  @paran aBekannt Gibt an, ob die Person bekannt ist (wahr) oder nicht (falsch)
     *  @return Objekt der erzeugten Person. Der Rckgabewert ist null, falls ein Fehler aufgetreten ist.
     */
    private PERSON registerPerson (String aName, boolean aBekannt)
    {
        if (aBekannt && (anzahlBekannte < bekannte.length))
        {
            PERSON p = new PERSON(aName,aBekannt);
            bekannte[anzahlBekannte] = p;
            anzahlBekannte++;
            return p;
        } else 
        if (!aBekannt && (anzahlUnbekannte < unbekannte.length))
        {
            PERSON p = new PERSON(aName,aBekannt);
            unbekannte[anzahlUnbekannte] = p;
            anzahlUnbekannte++;
            return p;
        } 
        System.out.println("Maximale Anzahl Personen ist erreicht: Person "+aName+" wurde nicht registriert."); 
        return null;
    }

    /**
     * Erzeugt ein Objekt der Klasse GESICHT mit den bergeben Parametern. Der Aufruf gibt eine Fehlermeldung aus, wenn kein
     * Speicherplatz merh fr das Gesicht zur Verfgung steht.
     * @param aPerson Person, fr die das Gesicht registiert werden soll
     * @param aGesichtName Name des zu registrierenden Gesichts, nicht der Person (z.B. Dateiname)
     * @param aKoords Feld mit den erfassten Koordinaten
     * @return Objekt des erzeugten Gesichts. Der Rckgabewert ist null, falls ein Fehler aufgetreten ist.
     */    
    private GESICHT registerGesicht(PERSON aPerson, String aGesichtName, double[] aKoords)
    {
        if (anzahlGesichter < gesichter.length) 
        {
            GESICHT g = new GESICHT(aPerson, aGesichtName, aKoords);   
            if (aPerson.addGesicht(g)) {                 // Versuche das Gesicht einzufgen
                gesichter[anzahlGesichter] = g;            // falls das geklappt hat, kann es auch in den zentrale Verwaltung
                anzahlGesichter++;
                return g;
            } 
            else
            {                                            // andernfalls braucht es dort auch nicht gespeichert werden 
                return null;
            }    

        }  
        System.out.println("Maximale Anzahl Gesichter ist erreicht: Gesicht "+aGesichtName+" wurde nicht registriert.");
        return null;
    }

    /**
     * Test-Methode: Gesichter sind groteils symmetrisch - die Symmetrie ist jedoch in der Regel nie perfekt. Mit dieser Methode 
     * kann die Frage untersucht werden, ob zwei Merkmale symmetrisch sind, d.h. bei jedem Gesicht bis auf geringe Abweichungen gleich 
     * gro sind.
     * 
     * @param merkmal1 Index des ersten Merkmals 
     * @param merkmal2 Index des zweiten Merkmals
     * @param abweichung Maximale Abweichung, die nicht angezeigt werden soll
     */
    public void reportSymmetrie(int merkmal1, int merkmal2, double abweichung)
    {
        System.out.println("");
        System.out.println("Symmetrie-Bericht fr Merkmal "+merkmal1+" und Merkmal "+merkmal2+":");
        for (int g=0; g < anzahlGesichter; g++)
        {
            double abw = Math.abs(gesichter[g].getMerkmal(merkmal1) - gesichter[g].getMerkmal(merkmal2));
            if (abw > abweichung)
            {
                System.out.println(gesichter[g].getPerson().getPersonName()+": "+gesichter[g].getGesichtName()+" ["+abw+"]");
            }
        }
    }

    /**
     * Test-Methode: Berechnet fr das bergeben Gesicht die Abstnde zu allen anderen Gesichtern. Die Ausgabe erfolgt 
     * fr alle Merkmale getrennt und als Summe.
     */
    public void reportAbstaende(GESICHT unbekannt)
    {
        System.out.println("Analyse fr unbekanntes Gesicht "+unbekannt.getPerson().getPersonName()+": "+unbekannt.getGesichtName());
        for (int g=0; g < anzahlGesichter; g++)
        {
            System.out.println("Vergleich mit "+gesichter[g].getPerson().getPersonName()+": "+gesichter[g].getGesichtName());
            System.out.println("  Abstand: "+abstand(unbekannt,gesichter[g],true));
        }
    }

    /**
     * Die Methode erzeugt im Feld gewichte eine zufllige Gewichtung (jedes Gewicht zwischen 0 und 0.9).
     * Anschlieend versucht die Methode alle unbekannten Personen zu identifizieren und berechnet die
     * Quote, der korrekten Identifizierung. Die Methode terminiert nicht.
     */
    public void reportZufaelligeGewichte()
    {
        int best = 0;
        while (true) {
            // Zufllige Gewichte erstellen
            for (int i=0; i<gewichte.length; i++) { gewichte[i] = (int) (10*Math.random())/10.0;}

            int richtig = 0;
            for (int u=0; u< anzahlUnbekannte; u++)
            {
                GESICHT ident = identifiziereGesicht(unbekannte[u].getGesicht(0),false);
                if (ident.getPerson().getPersonName() == unbekannte[u].getPersonName()) { richtig++; }
            }

            double quote = (double) richtig/anzahlUnbekannte;
            if (quote < 0.8)                      // hier je nach Wunsch < oder > Qualittsschranke eintragen
            {      
                System.out.print("Quote: "+quote);
                best = richtig;
                System.out.print(" Gewichte: ");
                for (int j = 0; j < gewichte.length; j++) {
                    System.out.print(gewichte[j]+" ");
                }
                System.out.println();
            }
        }
    }

    /**
     * Die Methode erzeugt einige bekannte und einige unbekannte Personen. Die Koordinaten stammen von realen Schlerinnen und Schlern, die unter 
     * gut kontrollierten  Aufnahmebedingungen fotografiert wurden. Zu allen Personen wurde mehrere Gesichter (Fotos) erfasst.
     *
     * Die "unbekannten" Testpersonen sind bekannt und tragen die gleichen Namen, wie die bekannten. Dies ermglicht die berprfung, ob eine Person 
     * richtig erkannt wurde oder nicht.
     * 
     * Fr die Speicherung derartige Daten wrde sich in einer realen biometrischen Anwendung z.B. relationale Datenbanken anbieten. Um die 
     * Komplexitt des Beispiels berschaubar zu halten, liefert die Methoden generateDemoData() aber auch entsprechende Daten, die direkt statisch
     * im Quelltext "gespeichert" vorliegen. Wer mag, kann statt dessen eine Datenbank verwenden. 
     */
    private void generateDemoData()
    {
        PERSON bekannt;
        PERSON unbekannt;

        // Person A: mnnlich, relativ einheitliche Bilder, Gesicht minimal schrggeneigt, kaum Gesichtsausdruck
        bekannt   = registerPerson("Person A", true);
        unbekannt = registerPerson("Person A", false);
        registerGesicht(bekannt,"A1",new double[]{-4.92,-0.20,-3.70,-1.83,-1.71,1.52,-2.31,1.24,-0.80,1.26,4.25,0.12,3.64,-1.85,1.61,1.42,0.76,1.24,2.41,1.14,-1.04,-0.49,1.03,-0.39,-1.37,-2.31,1.46,-2.41,-0.32,-1.74,0.38,-1.72,-0.08,-5.09,0.08,8.05,-3.62,1.24,3.45,1.07,-0.38,1.26,0.30,1.22});
        registerGesicht(bekannt,"A2",new double[]{-4.86,-0.20,-3.74,-1.74,-1.63,1.66,-2.36,1.34,-0.79,1.36,4.31,0.16,3.70,-1.81,1.62,1.56,0.88,1.32,2.46,1.26,-1.04,-0.49,1.03,-0.39,-1.35,-2.25,1.51,-2.29,-0.35,-1.54,0.40,-1.58,-0.08,-5.09,0.08,8.05,-3.63,1.34,3.50,1.22,-0.38,1.38,0.36,1.32});
        registerGesicht(unbekannt,"A3",new double[]{-4.73,-0.04,-3.55,-1.76,-1.59,1.64,-2.36,1.34,-0.74,1.38,4.39,0.16,3.84,-1.76,1.76,1.52,0.88,1.36,2.46,1.26,-1.04,-0.49,1.13,-0.41,-1.41,-2.21,1.56,-2.23,-0.35,-1.54,0.40,-1.58,-0.04,-5.07,0.15,8.15,-3.50,1.34,3.55,1.18,-0.38,1.38,0.39,1.38});
        registerGesicht(bekannt,"A4",new double[]{-4.64,-0.57,-3.50,-2.21,-1.58,1.42,-2.22,1.14,-0.76,1.20,4.51,0.04,3.83,-2.01,1.73,1.38,0.90,1.20,2.38,1.14,-1.04,-0.49,1.03,-0.39,-1.27,-2.37,1.48,-2.33,-0.30,-1.76,0.38,-1.72,0.06,-5.05,0.08,7.61,-3.42,1.10,3.53,1.07,-0.29,1.18,0.43,1.18});
        registerGesicht(bekannt,"A5",new double[]{-4.69,-0.61,-3.55,-2.13,-1.58,1.44,-2.29,1.16,-0.76,1.20,4.42,0.04,3.80,-1.95,1.73,1.38,0.90,1.20,2.38,1.14,-1.04,-0.49,1.03,-0.39,-1.27,-2.37,1.46,-2.25,-0.35,-1.72,0.36,-1.70,0.06,-5.05,0.08,7.75,-3.49,1.10,3.47,1.08,-0.29,1.18,0.43,1.18}); 

        // Person B: mnnlich, einige Bilder lachend, einige etwas schrggeneigt
        bekannt   = registerPerson("Person B", true);
        unbekannt = registerPerson("Person B", false);
        registerGesicht(unbekannt,"B1",new double[]{-6.04,0.61,-4.62,-1.52,-2.07,2.05,-2.77,1.81,-1.07,1.89,3.76,0.75,2.97,-1.40,1.28,2.03,0.56,1.91,2.16,1.79,-1.14,-0.26,1.05,-0.18,-1.85,-1.66,1.41,-1.58,-0.38,-1.28,0.33,-1.24,-0.21,-5.01,-0.40,8.40,-3.50,1.34,2.94,1.74,-0.57,1.87,0.11,1.89}); // lachend, schaut leicht zur Seite
        registerGesicht(bekannt,"B2",new double[]{-5.31,0.45,-3.97,-1.64,-1.76,1.91,-2.55,1.68,-0.88,1.81,4.51,0.75,3.52,-1.46,1.61,1.99,0.81,1.83,2.38,1.70,-1.14,-0.26,1.05,-0.18,-1.30,-1.97,1.37,-2.01,-0.29,-1.32,0.26,-1.30,0.02,-4.85,-0.11,8.34,-3.90,1.58,3.40,1.60,-0.32,1.81,0.23,1.81});  
        registerGesicht(bekannt,"B3",new double[]{-5.46,0.71,-4.17,-1.46,-1.88,2.13,-2.67,1.85,-0.88,1.87,4.44,0.95,3.40,-1.26,1.48,2.15,0.73,1.95,2.44,1.81,-1.14,-0.26,1.05,-0.18,-1.56,-1.58,1.55,-1.48,-0.28,-1.22,0.28,-1.22,0.19,-4.73,-0.39,8.48,-4.00,1.83,3.40,1.60,-0.45,1.91,0.21,1.91});  // lachend
        registerGesicht(bekannt,"B4",new double[]{-5.51,0.63,-4.13,-1.72,-1.93,1.85,-2.67,1.85,-0.96,1.87,4.34,0.89,3.26,-1.44,1.49,1.93,0.70,1.87,2.44,1.81,-1.04,-0.34,0.96,-0.28,-1.34,-1.97,1.28,-2.01,-0.36,-1.30,0.29,-1.30,-0.09,-4.69,-0.15,8.42,-4.00,1.83,3.28,1.78,-0.46,1.87,0.28,1.87});  // Augen fast zu
        registerGesicht(bekannt,"B5",new double[]{-5.51,0.63,-4.13,-1.72,-1.99,2.05,-2.77,1.76,-1.11,1.85,4.20,0.77,3.19,-1.56,1.44,2.01,0.59,1.85,2.44,1.81,-1.04,-0.30,0.86,-0.30,-1.37,-2.03,1.21,-2.01,-0.42,-1.38,0.28,-1.38,-0.19,-4.69,-0.32,8.34,-4.08,1.66,3.28,1.78,-0.54,1.85,0.08,1.85});
        registerGesicht(bekannt,"B6",new double[]{-5.61,0.49,-4.20,-1.68,-1.92,1.97,-2.75,1.72,-1.05,1.81,4.28,0.83,3.19,-1.56,1.46,1.97,0.63,1.81,2.36,1.64,-0.93,-0.41,0.94,-0.37,-1.38,-2.01,1.22,-2.07,-0.32,-1.44,0.30,-1.42,-0.19,-4.69,-0.32,8.34,-4.08,1.66,3.25,1.58,-0.53,1.79,0.09,1.79});  // leicht zur Seite schauend

        // Person C: weiblich, einige Bilder mit leicht geffneten Mund
        bekannt   = registerPerson("Person C", true);
        unbekannt = registerPerson("Person C", false);
        registerGesicht(bekannt,"C1",new double[]{-4.88,-0.14,-3.74,-2.39,-1.72,1.14,-2.58,0.97,-0.88,1.03,4.25,0.12,3.47,-2.17,1.61,1.22,0.94,1.05,2.43,1.07,-1.07,-0.59,1.10,-0.51,-1.22,-2.47,1.35,-2.27,-0.32,-1.52,0.39,-1.50,0.06,-4.71,-0.02,6.73,-3.66,0.93,3.36,1.07,-0.45,1.03,0.39,1.03}); // Mund leicht geffnet
        registerGesicht(unbekannt,"C2",new double[]{-4.88,-0.14,-3.74,-2.39,-1.71,1.08,-2.58,0.91,-0.88,1.03,4.25,0.12,3.47,-2.19,1.59,1.14,0.93,1.03,2.43,1.07,-1.07,-0.59,1.10,-0.51,-1.24,-2.47,1.32,-2.35,-0.28,-1.54,0.39,-1.54,0.06,-4.71,-0.02,6.55,-3.66,0.93,3.36,1.08,-0.45,1.03,0.39,1.03}); // Mund leicht geffnet
        registerGesicht(bekannt,"C3",new double[]{-4.82,-0.06,-3.74,-2.39,-1.71,1.08,-2.58,0.91,-0.88,1.03,4.27,-0.04,3.47,-2.19,1.59,1.14,0.93,1.03,2.46,1.05,-1.07,-0.63,1.14,-0.53,-1.27,-2.45,1.39,-2.37,-0.29,-1.58,0.39,-1.54,0.06,-4.71,-0.01,6.65,-3.69,0.83,3.36,1.08,-0.38,1.01,0.35,1.01}); // Mund leicht geffnet
        registerGesicht(bekannt,"C4",new double[]{-4.72,0.18,-3.74,-2.15,-1.62,1.24,-2.44,1.01,-0.84,1.05,4.41,0.00,3.47,-2.19,1.75,1.20,1.01,1.01,2.58,0.97,-1.07,-0.63,1.14,-0.53,-1.30,-2.35,1.46,-2.31,-0.29,-1.58,0.36,-1.60,0.06,-4.71,0.12,6.80,-3.60,0.99,3.50,0.93,-0.40,1.05,0.38,1.05});
        registerGesicht(bekannt,"C5",new double[]{-4.72,0.18,-3.74,-2.15,-1.62,1.24,-2.44,1.01,-0.83,1.10,4.41,0.00,3.52,-2.19,1.78,1.26,1.00,1.08,2.58,0.97,-1.00,-0.47,1.20,-0.45,-1.30,-2.23,1.45,-2.19,-0.29,-1.58,0.43,-1.56,0.06,-4.71,0.12,6.80,-3.56,0.97,3.52,0.91,-0.40,1.08,0.39,1.10});
        registerGesicht(bekannt,"C6",new double[]{-4.76,0.28,-3.74,-2.15,-1.62,1.24,-2.46,1.10,-0.83,1.10,4.38,0.14,3.52,-2.19,1.78,1.26,1.00,1.08,2.61,1.01,-1.03,-0.55,1.20,-0.45,-1.27,-2.31,1.46,-2.25,-0.29,-1.58,0.43,-1.54,0.06,-4.71,0.12,6.80,-3.56,1.07,3.52,0.97,-0.40,1.08,0.39,1.10});

        // Person D: weiblich, stark lockige Haar, Auenkante der Ohren daher nur geschtzt mglich
        bekannt   = registerPerson("Person D", true);
        unbekannt = registerPerson("Person D", false);
        registerGesicht(unbekannt,"D1",new double[]{-4.31,-0.30,-3.32,-2.19,-1.68,1.12,-2.38,0.89,-0.96,0.93,3.96,-0.12,3.16,-1.99,1.34,1.20,0.70,0.95,2.14,1.01,-0.86,-0.57,0.87,-0.61,-1.28,-2.15,1.25,-2.19,-0.25,-1.62,0.28,-1.60,-0.05,-4.69,-0.18,7.06,-3.33,0.87,3.29,1.05,-0.38,0.93,0.28,0.93}); // mit Brille
        registerGesicht(bekannt,"D2",new double[]{-4.17,-0.34,-3.35,-1.99,-1.63,1.16,-2.38,0.89,-0.93,0.97,3.96,-0.12,3.21,-1.79,1.37,1.20,0.67,0.97,2.14,1.01,-0.97,-0.51,0.94,-0.51,-1.28,-2.01,1.27,-1.97,-0.25,-1.38,0.29,-1.34,-0.05,-4.69,-0.12,7.30,-3.33,0.87,3.29,1.05,-0.36,0.97,0.26,0.97});
        registerGesicht(bekannt,"D3",new double[]{-4.17,-0.22,-3.38,-1.87,-1.66,1.22,-2.41,0.99,-0.91,1.10,3.94,0.02,3.21,-1.79,1.34,1.28,0.67,1.10,2.12,1.07,-0.98,-0.45,0.88,-0.47,-1.28,-2.07,1.18,-2.09,-0.30,-1.38,0.21,-1.40,-0.12,-4.62,-0.12,7.30,-3.29,0.93,3.22,1.03,-0.38,1.08,0.26,1.10});
        registerGesicht(bekannt,"D4",new double[]{-4.17,-0.22,-3.40,-1.95,-1.71,1.18,-2.41,0.99,-0.91,1.03,3.94,0.02,3.04,-1.87,1.27,1.26,0.69,1.07,2.12,1.07,-0.98,-0.45,0.81,-0.47,-1.27,-2.11,1.10,-2.09,-0.30,-1.38,0.18,-1.36,0.01,-4.58,-0.25,7.02,-3.29,0.93,3.22,1.03,-0.39,1.07,0.23,1.07});  // Bild unscharf, Mund leicht geffnet
        registerGesicht(bekannt,"D5",new double[]{-4.17,-0.22,-3.40,-1.95,-1.71,1.18,-2.41,0.99,-0.91,1.03,3.94,0.02,3.05,-1.81,1.34,1.22,0.69,1.07,2.09,1.07,-0.88,-0.41,0.83,-0.36,-1.27,-2.07,1.08,-2.01,-0.30,-1.44,0.16,-1.44,0.01,-4.58,-0.25,7.02,-3.21,0.95,3.06,1.05,-0.39,1.07,0.23,1.07}); // Bild unscharf

        // Person E: weiblich
        bekannt   = registerPerson("Person E", true);
        unbekannt = registerPerson("Person E", false);
        registerGesicht(bekannt,"E1",new double[]{-4.61,1.62,-3.79,-1.05,-1.54,1.68,-2.41,1.56,-0.79,1.50,4.62,1.10,4.08,-0.53,1.82,1.50,1.05,1.42,2.77,1.18,-0.80,-0.32,0.93,-0.43,-1.30,-1.93,1.30,-2.05,-0.38,-1.52,0.22,-1.54,-0.15,-4.62,0.40,8.05,-3.63,1.60,3.89,1.03,-0.26,1.50,0.49,1.46}); // leicht schrg geneigt
        registerGesicht(unbekannt,"E2",new double[]{-4.79,1.79,-3.98,-0.51,-1.62,1.85,-2.50,1.78,-0.80,1.62,4.56,1.58,3.70,-0.93,1.79,1.66,1.00,1.56,2.78,1.40,-0.98,-0.14,1.03,-0.28,-1.55,-1.50,1.38,-1.72,-0.40,-1.36,0.29,-1.42,-0.16,-4.42,0.30,8.36,-3.91,1.93,3.90,1.28,-0.30,1.58,0.52,1.58}); // schrg geneigt, lchelnd
        registerGesicht(bekannt,"E3",new double[]{-4.17,1.44,-3.46,-0.83,-1.38,1.83,-2.40,1.62,-0.67,1.58,5.26,1.16,4.10,-1.34,1.99,1.60,1.11,1.48,2.78,1.40,-0.87,-0.32,1.04,-0.39,-1.35,-1.97,1.58,-2.03,-0.35,-1.50,0.29,-1.56,-0.12,-4.71,0.57,8.13,-3.55,1.62,4.27,1.32,-0.21,1.56,0.56,1.50});
        registerGesicht(bekannt,"E4",new double[]{-4.59,1.58,-3.79,-0.83,-1.54,1.81,-2.48,1.66,-0.67,1.58,4.76,1.52,3.76,-1.14,1.90,1.64,1.11,1.48,2.78,1.40,-0.87,-0.32,1.04,-0.39,-1.37,-1.85,1.44,-1.99,-0.26,-1.56,0.29,-1.56,-0.12,-4.71,0.57,8.32,-3.62,1.72,4.00,1.32,-0.21,1.56,0.56,1.50});

        // Person F: mnnlich, leicht lchelnd, leicht schrg
        bekannt   = registerPerson("Person F", true);
        unbekannt = registerPerson("Person F", false);
        registerGesicht(bekannt,"F1",new double[]{-3.94,1.48,-3.28,-1.01,-1.45,1.76,-2.26,1.64,-0.77,1.56,4.83,0.91,3.74,-1.46,1.83,1.60,1.13,1.46,2.54,1.38,-0.96,-0.24,1.04,-0.39,-1.45,-1.66,1.49,-1.76,-0.25,-1.52,0.25,-1.52,-0.13,-4.38,0.50,7.71,-3.35,1.68,3.86,1.28,-0.30,1.50,0.59,1.46});
        registerGesicht(bekannt,"F2",new double[]{-4.00,1.28,-3.25,-1.34,-1.38,1.56,-2.22,1.42,-0.71,1.42,4.86,0.55,3.72,-1.76,1.89,1.42,1.17,1.36,2.58,1.24,-0.96,-0.24,1.04,-0.39,-1.41,-1.91,1.46,-1.99,-0.26,-1.58,0.26,-1.60,0.05,-4.44,0.43,7.24,-3.36,1.42,3.83,1.14,-0.28,1.40,0.59,1.34});
        registerGesicht(unbekannt,"F3",new double[]{-4.00,1.28,-3.25,-1.03,-1.34,1.68,-2.17,1.56,-0.66,1.48,4.86,0.55,3.86,-1.56,1.95,1.54,1.17,1.36,2.70,1.26,-0.96,-0.24,1.04,-0.39,-1.30,-1.87,1.51,-1.97,-0.28,-1.66,0.32,-1.70,-0.18,-4.48,0.62,7.51,-3.33,1.62,3.90,1.18,-0.23,1.46,0.63,1.40});
        registerGesicht(bekannt,"F4",new double[]{-4.00,1.24,-3.25,-1.03,-1.46,1.78,-2.24,1.74,-0.71,1.60,4.83,0.47,3.72,-1.42,1.78,1.66,1.11,1.56,2.61,1.38,-1.00,-0.18,0.93,-0.32,-1.46,-1.74,1.46,-1.85,-0.33,-1.52,0.21,-1.58,-0.01,-4.48,0.33,7.73,-3.33,1.83,3.91,1.24,-0.26,1.60,0.64,1.54});

        // Person G: weiblich
        bekannt   = registerPerson("Person G", true);
        unbekannt = registerPerson("Person G", false);
        registerGesicht(bekannt,"G1",new double[]{-4.42,0.61,-3.49,-1.85,-1.45,1.58,-2.26,1.40,-0.63,1.30,4.98,0.28,3.90,-1.89,1.82,1.58,0.86,1.28,2.74,1.32,-0.86,-0.45,1.04,-0.47,-1.45,-1.99,1.80,-1.83,-0.26,-1.48,0.42,-1.48,0.02,-4.52,0.16,7.12,-3.72,1.50,4.18,1.34,-0.11,1.30,0.47,1.26});
        registerGesicht(unbekannt,"G2",new double[]{-4.96,1.70,-3.77,-1.07,-1.63,1.95,-2.53,1.85,-0.83,1.66,4.44,1.56,3.62,-0.93,1.61,1.91,0.81,1.64,2.50,1.81,-0.84,-0.47,0.88,-0.41,-1.31,-2.01,1.44,-1.93,-0.36,-1.54,0.42,-1.54,-0.11,-4.42,0.04,8.32,-4.30,2.07,4.08,1.97,-0.30,1.64,0.38,1.62});  // Bild unter abweichenden Aufnahmebedingung (anderer Tag)
        registerGesicht(bekannt,"G3",new double[]{-5.31,0.77,-4.24,-1.56,-1.78,1.72,-2.67,1.62,-0.87,1.42,3.91,0.14,3.14,-1.87,1.46,1.56,0.62,1.36,2.34,1.30,-1.07,-0.36,0.73,-0.53,-1.73,-1.91,1.07,-2.15,-0.52,-1.58,0.13,-1.60,-0.25,-4.64,0.06,7.24,-4.56,1.79,3.73,1.22,-0.38,1.42,0.18,1.40});
        registerGesicht(bekannt,"G4",new double[]{-4.58,0.63,-3.63,-1.70,-1.59,1.68,-2.44,1.52,-0.67,1.38,4.76,0.39,3.76,-1.81,1.69,1.60,0.76,1.38,2.53,1.38,-0.91,-0.39,0.93,-0.41,-1.45,-1.95,1.49,-1.93,-0.45,-1.54,0.28,-1.60,-0.02,-4.60,0.06,7.24,-4.03,1.62,4.21,1.36,-0.26,1.38,0.33,1.36});  // lchelnd
        registerGesicht(bekannt,"G5",new double[]{-4.58,0.63,-3.63,-1.70,-1.52,1.68,-2.40,1.50,-0.64,1.38,4.76,0.39,3.83,-1.81,1.69,1.60,0.87,1.34,2.53,1.38,-0.91,-0.39,0.93,-0.41,-1.44,-2.03,1.54,-2.05,-0.32,-1.56,0.35,-1.58,-0.02,-4.60,0.23,7.18,-4.03,1.62,4.23,1.40,-0.26,1.38,0.33,1.36});

        // Person H: mnnlich
        bekannt   = registerPerson("Person H", true);
        unbekannt = registerPerson("Person H", false);
        registerGesicht(bekannt,"H1",new double[]{-4.73,0.69,-3.73,-1.28,-1.72,1.70,-2.60,1.44,-0.93,1.48,5.05,1.01,4.01,-0.97,1.73,1.87,0.87,1.56,2.63,1.66,-0.98,-0.41,0.98,-0.36,-1.46,-2.17,1.80,-1.81,-0.29,-1.66,0.52,-1.58,0.25,-4.64,-0.32,7.97,-3.93,1.40,3.86,1.70,-0.36,1.50,0.25,1.56}); // Gesicht leicht schrg
        registerGesicht(bekannt,"H2",new double[]{-4.78,0.53,-3.76,-1.38,-1.69,1.60,-2.58,1.30,-0.94,1.36,5.03,0.61,3.96,-1.30,1.76,1.62,0.98,1.44,2.61,1.48,-0.98,-0.41,1.03,-0.36,-1.44,-2.21,1.76,-1.85,-0.25,-1.68,0.42,-1.64,0.32,-4.85,-0.26,7.79,-3.97,1.28,3.91,1.50,-0.39,1.38,0.30,1.46});
        registerGesicht(unbekannt,"H3",new double[]{-4.78,0.53,-3.76,-1.38,-1.73,1.62,-2.61,1.32,-0.94,1.36,5.13,0.55,4.01,-1.36,1.83,1.66,0.98,1.44,2.68,1.44,-0.98,-0.41,1.03,-0.36,-1.48,-2.25,1.65,-2.17,-0.25,-1.68,0.42,-1.64,0.19,-4.85,-0.26,7.79,-3.97,1.28,3.97,1.42,-0.39,1.38,0.30,1.46}); // leicht geffneter Mund, Augen geschlossen (Position geschtzt)
        registerGesicht(bekannt,"H4",new double[]{-4.79,1.14,-3.70,-0.89,-1.72,1.83,-2.60,1.52,-0.91,1.58,5.27,1.32,4.08,-0.81,1.82,1.89,0.97,1.68,2.67,1.66,-1.00,-0.55,1.08,-0.36,-1.48,-2.07,1.76,-1.72,-0.25,-1.68,0.42,-1.64,0.38,-4.77,-0.38,8.54,-3.98,1.48,4.00,1.66,-0.40,1.66,0.35,1.62}); // Gesicht leicht schrg

        // Person I: weiblich, lange Haar, Ohren daher teilweise geschtzt
        bekannt   = registerPerson("Person I", true);
        unbekannt = registerPerson("Person I", false);
        registerGesicht(unbekannt,"I1",new double[]{-4.31,0.91,-3.73,-1.58,-1.52,1.50,-2.29,1.42,-0.79,1.30,4.18,0.71,3.73,-1.76,1.72,1.46,0.98,1.28,2.65,1.32,-1.00,-0.55,1.08,-0.36,-1.28,-2.21,1.42,-2.35,-0.26,-1.76,0.38,-1.81,-0.02,-5.01,0.18,6.69,-3.93,1.58,3.91,1.34,-0.32,1.30,0.43,1.24});
        registerGesicht(bekannt,"I2",new double[]{-4.32,0.89,-3.74,-1.46,-1.55,1.50,-2.29,1.42,-0.79,1.30,4.18,0.71,3.74,-1.66,1.73,1.52,0.98,1.28,2.65,1.32,-1.00,-0.55,1.08,-0.36,-1.38,-1.91,1.44,-2.07,-0.33,-1.56,0.40,-1.62,-0.02,-5.01,0.15,6.79,-3.93,1.58,3.91,1.34,-0.32,1.30,0.45,1.30});
        registerGesicht(bekannt,"I3",new double[]{-4.41,0.95,-3.81,-1.54,-1.56,1.40,-2.37,1.24,-0.79,1.30,4.18,0.71,3.70,-1.91,1.71,1.38,0.98,1.28,2.58,1.22,-0.91,-0.47,1.11,-0.55,-1.35,-2.23,1.37,-2.31,-0.29,-1.74,0.32,-1.76,-0.04,-5.11,0.13,6.63,-3.87,1.18,3.86,1.16,-0.32,1.30,0.35,1.28});
        registerGesicht(bekannt,"I4",new double[]{-4.37,0.91,-3.81,-1.54,-1.58,1.48,-2.41,1.34,-0.79,1.30,4.18,0.71,3.70,-1.91,1.68,1.46,0.98,1.28,2.58,1.22,-0.91,-0.47,1.11,-0.55,-1.35,-2.23,1.37,-2.31,-0.32,-1.64,0.32,-1.68,-0.04,-5.11,0.13,6.63,-3.87,1.36,3.86,1.16,-0.32,1.30,0.35,1.28});

        // Person J: weiblich
        bekannt   = registerPerson("Person J", true);
        unbekannt = registerPerson("Person J", false);
        registerGesicht(bekannt,"J1",new double[]{-4.98,0.89,-3.84,-1.18,-1.76,2.09,-2.64,1.78,-0.87,1.83,4.73,0.73,3.56,-1.28,1.68,1.99,0.77,1.83,2.57,1.54,-0.93,-0.12,0.81,-0.18,-1.56,-1.81,1.35,-1.91,-0.46,-1.44,0.35,-1.46,-0.06,-4.81,-0.06,8.34,-3.86,1.74,3.73,1.36,-0.42,1.81,0.29,1.83}); // Augen geschlossen, Pupille geschtzt
        registerGesicht(bekannt,"J2",new double[]{-5.07,1.03,-3.81,-0.91,-1.75,2.23,-2.57,2.09,-0.88,2.01,4.69,0.77,3.43,-1.18,1.68,2.07,0.76,1.97,2.50,1.78,-0.93,-0.12,0.81,-0.18,-1.51,-1.87,1.31,-1.87,-0.39,-1.34,0.33,-1.36,-0.25,-4.81,0.08,8.50,-3.84,2.13,3.67,1.66,-0.39,1.99,0.29,1.97}); // Mund geffnet
        registerGesicht(bekannt,"J3",new double[]{-4.90,0.73,-3.84,-1.18,-1.76,2.09,-2.57,1.93,-0.87,1.83,4.69,0.77,3.56,-1.28,1.68,1.99,0.77,1.83,2.50,1.78,-0.93,-0.12,0.81,-0.18,-1.51,-1.87,1.31,-1.87,-0.46,-1.44,0.35,-1.46,-0.06,-4.81,-0.06,8.34,-3.86,1.99,3.67,1.74,-0.42,1.83,0.29,1.83});
        registerGesicht(bekannt,"J4",new double[]{-4.98,0.89,-3.73,-1.07,-1.80,2.13,-2.70,1.91,-0.87,1.83,4.73,0.73,3.56,-1.28,1.65,2.07,0.77,1.83,2.51,1.81,-0.93,-0.22,0.81,-0.16,-1.56,-1.81,1.38,-1.85,-0.46,-1.44,0.36,-1.44,-0.06,-4.81,-0.05,8.44,-3.87,1.97,3.72,1.79,-0.42,1.81,0.29,1.83});
        registerGesicht(unbekannt,"J5",new double[]{-4.69,1.40,-3.52,-0.81,-1.72,2.21,-2.44,1.97,-0.84,2.03,4.81,1.05,3.69,-0.83,1.68,2.15,0.74,2.03,2.50,1.85,-0.80,-0.10,0.81,-0.04,-1.44,-1.60,1.31,-1.60,-0.53,-1.26,0.40,-1.30,-0.06,-4.81,-0.04,8.72,-3.80,1.91,3.70,1.76,-0.43,2.03,0.30,2.01}); // Augen halb geschlossen
        registerGesicht(bekannt,"J6",new double[]{-4.72,1.20,-3.52,-0.81,-1.61,2.31,-2.47,2.11,-0.84,2.03,4.95,1.14,3.69,-0.83,1.71,2.29,0.74,2.03,2.50,2.01,-0.80,-0.10,0.81,-0.04,-1.44,-1.60,1.31,-1.60,-0.46,-1.20,0.30,-1.18,-0.06,-4.81,-0.04,8.72,-3.69,2.17,3.73,1.99,-0.39,2.01,0.30,2.01});
        registerGesicht(bekannt,"J7",new double[]{-4.72,1.20,-3.52,-0.81,-1.62,2.23,-2.47,2.11,-0.84,2.03,4.95,1.14,3.69,-0.83,1.72,2.19,0.74,2.03,2.50,2.01,-0.80,-0.10,0.88,-0.12,-1.31,-1.72,1.30,-1.68,-0.47,-1.32,0.30,-1.32,-0.06,-4.81,-0.04,8.72,-3.69,2.17,3.73,1.99,-0.39,2.01,0.30,2.01});
        registerGesicht(bekannt,"J8",new double[]{-4.55,1.34,-3.43,-0.81,-1.66,2.25,-2.47,2.11,-0.84,2.03,5.07,1.20,3.80,-0.75,1.72,2.19,0.74,2.03,2.50,2.01,-0.80,-0.10,0.88,-0.12,-1.41,-1.64,1.44,-1.66,-0.30,-1.34,0.38,-1.36,-0.06,-4.81,-0.01,9.01,-3.60,2.17,3.79,2.01,-0.39,2.01,0.30,2.01});

        // Person K: weiblich
        bekannt   = registerPerson("Person K", true);
        unbekannt = registerPerson("Person K", false);
        registerGesicht(bekannt,"K1",new double[]{-5.00,0.24,-3.81,-1.72,-2.02,1.24,-2.71,1.07,-1.07,1.03,4.00,0.26,3.08,-1.66,1.37,1.32,0.64,1.07,2.36,1.10,-1.04,-0.63,0.81,-0.59,-1.59,-2.23,1.22,-2.21,-0.40,-1.76,0.23,-1.78,-0.06,-4.81,-0.35,7.30,-4.14,1.10,3.49,1.08,-0.52,1.05,0.30,1.07}); 
        registerGesicht(bekannt,"K2",new double[]{-4.52,0.22,-3.49,-1.70,-1.88,1.26,-2.71,1.07,-1.00,1.05,4.44,0.26,3.49,-1.72,1.52,1.26,0.83,1.08,2.46,1.01,-1.05,-0.73,0.84,-0.71,-1.46,-2.37,1.24,-2.35,-0.43,-1.91,0.19,-1.91,0.04,-4.95,-0.23,7.26,-3.79,1.10,3.67,0.93,-0.52,1.05,0.36,1.07}); 
        registerGesicht(bekannt,"K3",new double[]{-4.32,0.39,-3.49,-1.70,-1.80,1.26,-2.65,1.07,-0.96,1.05,4.65,0.34,3.56,-1.58,1.52,1.26,0.83,1.08,2.50,1.07,-0.93,-0.67,0.93,-0.67,-1.35,-2.23,1.39,-2.17,-0.35,-1.87,0.28,-1.87,0.04,-4.95,-0.23,7.26,-3.67,1.10,3.80,1.03,-0.52,1.05,0.36,1.07}); 
        registerGesicht(bekannt,"K4",new double[]{-4.42,-0.02,-3.42,-1.93,-1.88,1.18,-2.63,0.99,-0.96,1.05,4.76,0.20,3.60,-1.79,1.55,1.28,0.83,1.08,2.50,1.07,-0.93,-0.67,0.93,-0.67,-1.37,-2.43,1.41,-2.33,-0.32,-1.93,0.30,-1.91,0.04,-4.95,-0.21,7.32,-3.66,0.97,3.80,1.03,-0.52,1.05,0.36,1.07}); 
        registerGesicht(unbekannt,"K5",new double[]{-4.81,0.53,-3.63,-1.36,-1.73,1.12,-2.63,0.99,-0.96,1.05,3.76,0.43,2.82,-1.44,1.45,1.10,0.64,1.03,2.20,0.95,-0.96,-0.65,0.71,-0.57,-1.46,-2.05,1.07,-2.11,-0.45,-1.76,0.11,-1.78,-0.19,-4.97,-0.16,7.22,-3.81,0.93,3.19,0.91,-0.52,1.07,0.26,1.03});  // abweichende Blickrichtung
        registerGesicht(bekannt,"K6",new double[]{-4.86,0.73,-3.74,-1.12,-1.73,1.12,-2.63,1.14,-0.94,1.12,3.64,0.49,2.78,-1.36,1.37,1.26,0.66,1.14,2.23,1.03,-0.93,-0.43,0.81,-0.51,-1.45,-1.85,1.03,-1.95,-0.49,-1.58,0.15,-1.62,-0.19,-4.97,-0.16,7.22,-3.87,1.16,3.19,0.91,-0.50,1.12,0.30,1.12}); 
        registerGesicht(bekannt,"K7",new double[]{-4.89,0.79,-3.74,-1.12,-1.79,1.38,-2.63,1.14,-0.94,1.12,3.64,0.49,2.78,-1.36,1.37,1.26,0.66,1.14,2.23,1.03,-0.93,-0.43,0.81,-0.51,-1.45,-1.85,1.03,-1.95,-0.49,-1.58,0.15,-1.62,-0.09,-4.87,-0.16,7.22,-3.87,1.16,3.04,0.97,-0.50,1.12,0.30,1.12}); 
        registerGesicht(bekannt,"K8",new double[]{-4.95,0.75,-3.74,-1.12,-1.79,1.38,-2.63,1.14,-1.00,1.16,3.64,0.43,2.78,-1.36,1.34,1.34,0.66,1.14,2.23,1.03,-0.98,-0.45,0.74,-0.45,-1.45,-1.85,1.03,-1.95,-0.49,-1.52,0.15,-1.58,-0.19,-4.85,-0.16,7.22,-3.87,1.16,3.04,0.97,-0.50,1.12,0.30,1.12}); 

        // Person L: mnnlich
        bekannt   = registerPerson("Person L", true);
        unbekannt = registerPerson("Person L", false);
        registerGesicht(bekannt,"L1",new double[]{-5.70,-0.32,-4.54,-2.52,-2.16,1.30,-3.05,1.05,-1.28,1.14,4.31,0.08,3.50,-2.15,1.52,1.48,0.69,1.14,2.27,1.22,-1.32,-0.59,1.11,-0.57,-1.58,-2.43,1.73,-2.17,-0.46,-1.87,0.42,-1.81,-0.29,-5.36,-0.30,7.42,-4.66,0.97,3.55,1.28,-0.76,1.12,0.25,1.14}); 
        registerGesicht(unbekannt,"L2",new double[]{-5.77,-0.24,-4.56,-2.47,-2.22,1.28,-3.05,1.05,-1.28,1.14,4.24,0.22,3.40,-2.15,1.52,1.52,0.69,1.20,2.27,1.22,-1.32,-0.59,1.13,-0.57,-1.58,-2.43,1.61,-2.23,-0.53,-1.93,0.35,-1.91,-0.15,-5.35,-0.46,7.48,-4.66,0.97,3.55,1.28,-0.76,1.12,0.26,1.18}); 
        registerGesicht(bekannt,"L3",new double[]{-5.74,-0.28,-4.45,-2.58,-2.22,1.28,-3.05,1.05,-1.30,1.12,4.24,0.22,3.43,-2.21,1.52,1.52,0.69,1.18,2.27,1.22,-1.35,-0.69,1.11,-0.57,-1.62,-2.50,1.65,-2.35,-0.47,-1.89,0.45,-1.83,-0.15,-5.35,-0.46,7.48,-4.66,0.97,3.55,1.28,-0.76,1.12,0.26,1.18}); 
        registerGesicht(bekannt,"L4",new double[]{-5.68,0.04,-4.48,-2.21,-2.03,1.38,-3.05,1.05,-1.30,1.12,4.42,0.00,3.45,-2.19,1.59,1.44,0.69,1.18,2.27,1.22,-1.25,-0.59,1.08,-0.61,-1.63,-2.43,1.55,-2.33,-0.50,-1.83,0.40,-1.81,-0.15,-5.35,-0.50,7.59,-4.66,0.97,3.55,1.28,-0.76,1.12,0.26,1.18}); 
        registerGesicht(bekannt,"L5",new double[]{-5.81,0.04,-4.68,-2.21,-2.19,1.38,-3.05,1.05,-1.30,1.12,4.27,0.06,3.35,-2.21,1.39,1.44,0.69,1.18,2.27,1.22,-1.25,-0.59,1.01,-0.59,-1.69,-2.45,1.46,-2.37,-0.53,-1.83,0.28,-1.81,-0.15,-5.35,-0.50,7.59,-4.66,0.97,3.55,1.28,-0.76,1.12,0.26,1.18}); 
        registerGesicht(bekannt,"L6",new double[]{-5.64,0.08,-4.64,-2.29,-2.07,1.36,-2.91,1.10,-1.30,1.12,4.42,0.12,3.38,-2.19,1.55,1.42,0.69,1.18,2.27,1.22,-1.25,-0.59,1.01,-0.59,-1.73,-2.41,1.48,-2.29,-0.49,-1.79,0.36,-1.76,-0.15,-5.35,-0.50,7.59,-4.72,1.07,3.55,1.28,-0.76,1.12,0.26,1.18}); 

        // Person M: mnnlich
        bekannt   = registerPerson("Person M", true);
        unbekannt = registerPerson("Person M", false);
        registerGesicht(bekannt,"M1",new double[]{-5.19,1.30,-4.04,-0.37,-2.00,2.13,-2.88,1.89,-1.14,1.95,4.39,2.47,3.60,0.12,1.51,2.39,0.69,2.03,2.37,2.23,-1.04,-0.06,0.93,0.04,-1.62,-1.42,1.59,-1.36,-0.40,-0.93,0.38,-0.93,0.04,-4.02,-0.57,9.78,-4.42,1.83,3.49,2.37,-0.67,1.95,0.25,2.03}); 
        registerGesicht(bekannt,"M2",new double[]{-5.19,1.30,-4.04,-0.37,-1.93,2.13,-2.88,1.89,-1.14,1.95,4.45,2.45,3.60,0.02,1.54,2.39,0.69,2.03,2.37,2.23,-1.04,-0.06,0.93,0.04,-1.62,-1.42,1.59,-1.36,-0.40,-0.93,0.50,-0.89,0.04,-4.02,-0.57,9.66,-4.42,1.83,3.49,2.37,-0.67,1.95,0.25,2.03}); 
        registerGesicht(unbekannt,"M3",new double[]{-5.48,1.44,-4.25,-0.18,-2.00,2.17,-2.88,1.95,-1.14,1.95,4.23,2.25,3.33,-0.06,1.54,2.31,0.69,2.03,2.36,2.11,-1.13,0.00,0.93,0.04,-1.83,-1.34,1.48,-1.38,-0.57,-0.95,0.39,-0.93,0.04,-4.02,-0.57,9.66,-4.49,1.97,3.39,2.15,-0.67,1.95,0.25,2.03}); // leicht andere Blickrichtung
        registerGesicht(bekannt,"M4",new double[]{-5.31,1.62,-4.25,-0.18,-2.00,2.17,-2.88,1.95,-1.14,1.95,4.31,2.21,3.33,-0.06,1.54,2.31,0.69,2.03,2.40,2.01,-1.13,0.00,0.93,0.04,-1.83,-1.34,1.48,-1.38,-0.57,-0.95,0.39,-0.93,0.04,-4.02,-0.57,9.72,-4.49,1.97,3.43,2.01,-0.54,1.99,0.28,2.03}); // Augen geschlossen, Pupille geschtzt

    }

}
